.noembed-wrapper {
  display: inline-block;
}

.noembed-embed-inner {
  padding: 5px;
  overflow: hidden;
  border: 1px solid #ddd;
  border-right: 1px solid #bbb;
  border-bottom: none;
  background: #fff;
  color: #000;
  font-size: 12px;
}

.noembed-embed .noembed-meta-info {
  background: #efefef;
  width: 100%;
  font-size: 10px;
  color: #666;
  border: 1px solid #ddd;
  border-top: none;
  border-right: 1px solid #bbb;
  border-bottom: 1px solid #bbb;
}

.noembed-embed .noembed-meta-info td {
  vertical-align: middle;
  line-height: 1em;
  padding-top: 2px;
  padding-bottom: 2px;
}

.noembed-embed .noembed-meta-info td:first-child {
  padding-left: 5px;
}

.noembed-embed .noembed-meta-info td:last-child {
  padding-right: 5px;
}

.noembed-embed .noembed-meta-info a {
  text-decoration: none;
  color: #666;
  font-weight: bold;
}

.noembed-embed .favicon {
  height: 16px;
  width: 16px;
}
.noembed-embed .favicon img {
  width: 16px;
  width: 16px;
  display: inline-block;
  margin: 0;
  padding: 0;
  border: none;
}





.noembed-twittercard {
  padding: 10px;
}

.noembed-twittercard img {
  float: right;
  margin-left: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-twittercard h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-twittercard a {
  text-decoration: none;
}

.noembed-twittercard p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}


.noembed-twittercard {
  padding: 10px;
}

.noembed-twittercard img {
  float: right;
  margin-left: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-twittercard h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-twittercard a {
  text-decoration: none;
}

.noembed-twittercard p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}

.noembed-twittercard {
  padding: 10px;
}

.noembed-twittercard img {
  float: right;
  margin-left: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-twittercard h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-twittercard a {
  text-decoration: none;
}

.noembed-twittercard p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}

.noembed-twittercard {
  padding: 10px;
}

.noembed-twittercard img {
  float: right;
  margin-left: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-twittercard h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-twittercard a {
  text-decoration: none;
}

.noembed-twittercard p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}


.noembed-twittercard {
  padding: 10px;
}

.noembed-twittercard img {
  float: right;
  margin-left: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-twittercard h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-twittercard a {
  text-decoration: none;
}

.noembed-twittercard p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}

.noembed-twittercard {
  padding: 10px;
}

.noembed-twittercard img {
  float: right;
  margin-left: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-twittercard h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-twittercard a {
  text-decoration: none;
}

.noembed-twittercard p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}



.noembed-gist h2 {
  font-weight: normal;
  font-size: 1.2em;
  margin: 0;
  padding: 0;
  padding-bottom: 5px;
  border-bottom: 1px solid #eee;
}

.noembed-gist h3 {
  font-weight: normal;
  margin: 0;
  padding: 0;
  font-size: 1em;
}

.noembed-gist .gist-language {
  float: right;
  color: #999;
}

.noembed-gist .gist-file {
  background: #efefef;
  overflow-x: auto;
  margin-top: 5px;
  max-height: 300px;
}

.noembed-gist .gist-file table {
  font-size: 1em;
}

.noembed-gist .gist-description {
  font-size: 1.5em;
  font-weight: bold;
  margin: 0;
  padding: 5px;
  color: #111;
  overflow: hidden;
}

.noembed-gist a {
  color: #111;
  text-decoration: underline;
}

.noembed-gist table {
  width: auto;
  table-layout: auto;
  height: auto;
}

.noembed-gist .gist-description a:hover {
  text-decoration: underline;
}

.noembed-gist .gist-user {
  float: right;
}

.noembed-gist .gist-file pre {
  margin: 0;
  font-family: Menlo, DejaVuSansMono, monospace;
}

.noembed-gist .gist-file table {
  margin: 0;
  padding: 0;
  border-spacing: 0px;
}

.noembed-gist .gist-file td.linenos {
  color: #eee;
  background: #bbb;
  text-align: right;
  padding: 5px;
  border-right: 1px solid #aaa;
}

.noembed-gist .gist-file td.code {
  padding: 5px;
}

.hll { background-color: #ffffcc }
.c { color: #408080; font-style: italic } /* Comment */
.err { border: 1px solid #FF0000 } /* Error */
.k { color: #008000; font-weight: bold } /* Keyword */
.o { color: #666666 } /* Operator */
.cm { color: #408080; font-style: italic } /* Comment.Multiline */
.cp { color: #BC7A00 } /* Comment.Preproc */
.c1 { color: #408080; font-style: italic } /* Comment.Single */
.cs { color: #408080; font-style: italic } /* Comment.Special */
.gd { color: #A00000 } /* Generic.Deleted */
.ge { font-style: italic } /* Generic.Emph */
.gr { color: #FF0000 } /* Generic.Error */
.gh { color: #000080; font-weight: bold } /* Generic.Heading */
.gi { color: #00A000 } /* Generic.Inserted */
.go { color: #808080 } /* Generic.Output */
.gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.gs { font-weight: bold } /* Generic.Strong */
.gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.gt { color: #0040D0 } /* Generic.Traceback */
.kc { color: #008000; font-weight: bold } /* Keyword.Constant */
.kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
.kn { color: #008000; font-weight: bold } /* Keyword.Namespace */
.kp { color: #008000 } /* Keyword.Pseudo */
.kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
.kt { color: #B00040 } /* Keyword.Type */
.m { color: #666666 } /* Literal.Number */
.s { color: #BA2121 } /* Literal.String */
.na { color: #7D9029 } /* Name.Attribute */
.nb { color: #008000 } /* Name.Builtin */
.nc { color: #0000FF; font-weight: bold } /* Name.Class */
.no { color: #880000 } /* Name.Constant */
.nd { color: #AA22FF } /* Name.Decorator */
.ni { color: #999999; font-weight: bold } /* Name.Entity */
.ne { color: #D2413A; font-weight: bold } /* Name.Exception */
.nf { color: #0000FF } /* Name.Function */
.nl { color: #A0A000 } /* Name.Label */
.nn { color: #0000FF; font-weight: bold } /* Name.Namespace */
.nt { color: #008000; font-weight: bold } /* Name.Tag */
.nv { color: #19177C } /* Name.Variable */
.ow { color: #AA22FF; font-weight: bold } /* Operator.Word */
.w { color: #bbbbbb } /* Text.Whitespace */
.mf { color: #666666 } /* Literal.Number.Float */
.mh { color: #666666 } /* Literal.Number.Hex */
.mi { color: #666666 } /* Literal.Number.Integer */
.mo { color: #666666 } /* Literal.Number.Oct */
.sb { color: #BA2121 } /* Literal.String.Backtick */
.sc { color: #BA2121 } /* Literal.String.Char */
.sd { color: #BA2121; font-style: italic } /* Literal.String.Doc */
.s2 { color: #BA2121 } /* Literal.String.Double */
.se { color: #BB6622; font-weight: bold } /* Literal.String.Escape */
.sh { color: #BA2121 } /* Literal.String.Heredoc */
.si { color: #BB6688; font-weight: bold } /* Literal.String.Interpol */
.sx { color: #008000 } /* Literal.String.Other */
.sr { color: #BB6688 } /* Literal.String.Regex */
.s1 { color: #BA2121 } /* Literal.String.Single */
.ss { color: #19177C } /* Literal.String.Symbol */
.bp { color: #008000 } /* Name.Builtin.Pseudo */
.vc { color: #19177C } /* Name.Variable.Class */
.vg { color: #19177C } /* Name.Variable.Global */
.vi { color: #19177C } /* Name.Variable.Instance */
.il { color: #666666 } /* Literal.Number.Integer.Long */


.noembed-wikipedia {
  padding: 5px 10px;
}

.noembed-wikipedia p {
  margin: 0.5em 0;
  line-height: 1.4em;
}

.noembed-wikipedia sup {
  line-height: 0px;
}

.noembed-wikipedia div.tright,
.noembed-wikipedia div.floatright,
.noembed-wikipedia table.floattright {
  float: right;
  clear: right;
}

.noembed-wikipedia div.tright {
  margin: .5em 0 1.3em 1.4em;
}





.noembed-twittercard {
  padding: 10px;
}

.noembed-twittercard img {
  float: right;
  margin-left: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-twittercard h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-twittercard a {
  text-decoration: none;
}

.noembed-twittercard p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}

.noembed-bash {
  padding: 10px;
  border: 1px solid #ddd;
  border-right: 1px solid #bbb;
  border-bottom: 1px solid #bbb;
  background: #fff;
  overflow: hidden;
  font-family: Menlo, monospace;
}

.noembed-twittercard {
  padding: 10px;
}

.noembed-twittercard img {
  float: right;
  margin-left: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-twittercard h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-twittercard a {
  text-decoration: none;
}

.noembed-twittercard p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}


.noembed-asciiartfarts {
  padding: 0;
  border: none;
}

.noembed-asciiartfarts pre {
  padding: 5px 10px;
  display: block;
  float: left;
  background: #000;
  color: #fff;
  font-weight: bold;  
  margin: 0;
}

.noembed-monoprice {
  padding: 10px;
}

.noembed-monoprice img {
  float: left;
  margin-right: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-monoprice h2 {
  margin: 0 0 10px 0;
  font-size: 1.2em;
}

.noembed-monoprice a {
  text-decoration: none;
}

.noembed-twittercard {
  padding: 10px;
}

.noembed-twittercard img {
  float: right;
  margin-left: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-twittercard h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-twittercard a {
  text-decoration: none;
}

.noembed-twittercard p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}

.noembed-giantbomb p,
.noembed-youtube p {
  margin: 0;
  padding: 0;
}

.noembed-github {
  display: block;
}

.noembed-github p {
  padding: 5px 0;
  font-size: 12px;
  margin: 0 5px;
}

.noembed-github .github-stats {
  float: right;
  font-weight: bold;
}

.noembed-github .github-addition {
  color: #00A000;
}

.noembed-github .github-deletion {
  color: #A00000;
}

.noembed-github .github-change {
  border-top: 1px solid #eee;
  padding: 5px;
}

.noembed-github .github-file {
  background: #efefef;
  overflow-x: auto;
  margin: 5px 0;
  max-height: 300px;
  display: none;
}

.noembed-github .github-file.visible {
  display: block;
}

.noembed-github .github-file table {
  font-size: 12px;
}

.noembed-github .github-description {
  font-weight: bold;
  margin: 0;
  padding: 5px;
  color: #111;
  overflow: hidden;
}

.noembed-github a {
  color: #111;
  text-decoration: underline;
}

.noembed-github table {
  width: auto;
  table-layout: auto;
  height: auto;
}

.noembed-github .github-description a:hover {
  text-decoration: underline;
}

.noembed-github .github-user {
  float: right;
}

.noembed-github .github-file pre {
  margin: 0;
  font-family: Menlo, DejaVuSansMono, monospace;
}

.noembed-github .github-file table {
  margin: 0;
  padding: 0;
  border-spacing: 0px;
}

.noembed-github .github-file td.linenos {
  color: #eee;
  background: #bbb;
  text-align: right;
  padding: 5px;
  border-right: 1px solid #aaa;
}

.noembed-github .github-file td.code {
  padding: 5px;
}

.hll { background-color: #ffffcc }
.c { color: #408080; font-style: italic } /* Comment */
.err { border: 1px solid #FF0000 } /* Error */
.k { color: #008000; font-weight: bold } /* Keyword */
.o { color: #666666 } /* Operator */
.cm { color: #408080; font-style: italic } /* Comment.Multiline */
.cp { color: #BC7A00 } /* Comment.Preproc */
.c1 { color: #408080; font-style: italic } /* Comment.Single */
.cs { color: #408080; font-style: italic } /* Comment.Special */
.gd { color: #A00000 } /* Generic.Deleted */
.ge { font-style: italic } /* Generic.Emph */
.gr { color: #FF0000 } /* Generic.Error */
.gh { color: #000080; font-weight: bold } /* Generic.Heading */
.gi { color: #00A000 } /* Generic.Inserted */
.go { color: #808080 } /* Generic.Output */
.gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.gs { font-weight: bold } /* Generic.Strong */
.gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.gt { color: #0040D0 } /* Generic.Traceback */
.kc { color: #008000; font-weight: bold } /* Keyword.Constant */
.kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
.kn { color: #008000; font-weight: bold } /* Keyword.Namespace */
.kp { color: #008000 } /* Keyword.Pseudo */
.kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
.kt { color: #B00040 } /* Keyword.Type */
.m { color: #666666 } /* Literal.Number */
.s { color: #BA2121 } /* Literal.String */
.na { color: #7D9029 } /* Name.Attribute */
.nb { color: #008000 } /* Name.Builtin */
.nc { color: #0000FF; font-weight: bold } /* Name.Class */
.no { color: #880000 } /* Name.Constant */
.nd { color: #AA22FF } /* Name.Decorator */
.ni { color: #999999; font-weight: bold } /* Name.Entity */
.ne { color: #D2413A; font-weight: bold } /* Name.Exception */
.nf { color: #0000FF } /* Name.Function */
.nl { color: #A0A000 } /* Name.Label */
.nn { color: #0000FF; font-weight: bold } /* Name.Namespace */
.nt { color: #008000; font-weight: bold } /* Name.Tag */
.nv { color: #19177C } /* Name.Variable */
.ow { color: #AA22FF; font-weight: bold } /* Operator.Word */
.w { color: #bbbbbb } /* Text.Whitespace */
.mf { color: #666666 } /* Literal.Number.Float */
.mh { color: #666666 } /* Literal.Number.Hex */
.mi { color: #666666 } /* Literal.Number.Integer */
.mo { color: #666666 } /* Literal.Number.Oct */
.sb { color: #BA2121 } /* Literal.String.Backtick */
.sc { color: #BA2121 } /* Literal.String.Char */
.sd { color: #BA2121; font-style: italic } /* Literal.String.Doc */
.s2 { color: #BA2121 } /* Literal.String.Double */
.se { color: #BB6622; font-weight: bold } /* Literal.String.Escape */
.sh { color: #BA2121 } /* Literal.String.Heredoc */
.si { color: #BB6688; font-weight: bold } /* Literal.String.Interpol */
.sx { color: #008000 } /* Literal.String.Other */
.sr { color: #BB6688 } /* Literal.String.Regex */
.s1 { color: #BA2121 } /* Literal.String.Single */
.ss { color: #19177C } /* Literal.String.Symbol */
.bp { color: #008000 } /* Name.Builtin.Pseudo */
.vc { color: #19177C } /* Name.Variable.Class */
.vg { color: #19177C } /* Name.Variable.Global */
.vi { color: #19177C } /* Name.Variable.Instance */
.il { color: #666666 } /* Literal.Number.Integer.Long */

.noembed-spotify {
  background: #373737;
  color: #999;
  font-size: 1.2em;
  padding: 10px;
  max-width: 500px;
  border: none;
}

.noembed-spotify a {
  color: #B3B3B3;
  text-decoration: underline;
}

.noembed-spotify span.spotify-title {
  font-size: 1.5em;
  display: block;
}
.noembed-spotify span.spotify-title a {
  color: #fff;
  text-decoration: none;
}

.noembed-spotify img {
  float: left;
  margin-right: 10px;
}





.noembed-beeradvocate table td {
  font-size: 11px;
}
.noembed-beeradvocate span.BAscore_big {
  font-size: 22px;
  color: #c00;
  font-weight: bold;
}

.noembed-imdb {
  padding: 10px;
}

.noembed-imdb img {
  float: left;
  margin-right: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-imdb h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-imdb a {
  text-decoration: none;
}

.noembed-imdb ul.imdb-metadata {
  overflow: hidden;  
  padding: 0;
  margin: 0;
  margin-top: 0.2em;
}

.noembed-imdb ul.imdb-metadata li {
  display: inline-block;
  padding: 0;
  margin: 0;
  margin-right: 5px;
  color: #bbb;
  font-weight: bold;
  font-size: 0.8em;
}

.noembed-imdb p.imdb-overview {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}




.noembed-twitter {
  padding: 0;
  max-width: 500px;
  font-size: 16px;
}
.noembed-twitter a {
  text-decoration: none;
}
.noembed-twitter a:hover {
  text-decoration: underline;
}

.noembed-twitter .tweet_main {
  padding: 10px;
}

.noembed-twitter div.tweet_image img {
  display: block;
}
.noembed-twitter div.tweet_image {
  float: left;
  margin-right: 5px;
}
.noembed-twitter div.tweet_text {
  clear: both;
  padding: 0.5em 0;
}
.noembed-twitter .tweet_screen_name {
  font-weight: bold;
  color: #000;
}
.noembed-twitter .tweet_real_name {
  font-weight: normal;
  font-size: 12px;
  color: #999;
}

.noembed-twitter div.tweet_info a,
.noembed-twitter div.tweet_info {
  font-size: 12px;
  color: #999;
}

.noembed-twitter div.tweet_info div {
  display: inline;
}


.noembed-amazon {
  padding: 10px;
}

.noembed-amazon img {
  float: left;
  margin-right: 10px;
  background: #efefef;
  border: 1px solid #ddd;
}

.noembed-amazon h2 {
  margin: 0;
  font-size: 1.2em;
}

.noembed-amazon a {
  text-decoration: none;
}

.noembed-amazon ul {
  overflow: hidden;  
  padding: 0;
  margin: 0;
  margin-top: 0.2em;
}

.noembed-amazon ul li {
  display: inline-block;
  padding: 0;
  margin: 0;
  margin-right: 5px;
  color: #bbb;
  font-weight: bold;
  font-size: 0.8em;
}

.noembed-amazon p {
  margin: 0;
  padding: 0;
  margin-top: 0.8em;
}








.noembed-urbandictionary {
  padding: 10px;
}
.noembed-urbandictionary h2 {
  margin: 0;
  margin-bottom: 5px;
}


