{% load waliki_tags %}
{% if extra_page_actions %}
    {% for url_name, action in extra_page_actions.all %}
        <li><a href="{% url url_name page.slug %}" rel="nofollow">{{ action }}</a></li>
    {% endfor %}
    {% for url_name, action in extra_page_actions|getattr:page.markup %}
        <li><a href="{% url url_name page.slug %}" rel="nofollow">{{ action }}</a></li>
    {% endfor %}

{% endif %}