code .hll { background-color: #ffffcc }
code  { background: #f8f8f8; }
code .c { color: #8f5902; font-style: italic } /* Comment */
code .err { color: #a40000; border: 1px solid #ef2929 } /* Error */
code .g { color: #000000 } /* Generic */
code .k { color: #204a87; font-weight: bold } /* Keyword */
code .l { color: #000000 } /* Literal */
code .n { color: #000000 } /* Name */
code .o { color: #ce5c00; font-weight: bold } /* Operator */
code .x { color: #000000 } /* Other */
code .p { color: #000000; font-weight: bold } /* Punctuation */
code .cm { color: #8f5902; font-style: italic } /* Comment.Multiline */
code .cp { color: #8f5902; font-style: italic } /* Comment.Preproc */
code .c1 { color: #8f5902; font-style: italic } /* Comment.Single */
code .cs { color: #8f5902; font-style: italic } /* Comment.Special */
code .gd { color: #a40000 } /* Generic.Deleted */
code .ge { color: #000000; font-style: italic } /* Generic.Emph */
code .gr { color: #ef2929 } /* Generic.Error */
code .gh { color: #000080; font-weight: bold } /* Generic.Heading */
code .gi { color: #00A000 } /* Generic.Inserted */
code .go { color: #000000; font-style: italic } /* Generic.Output */
code .gp { color: #8f5902 } /* Generic.Prompt */
code .gs { color: #000000; font-weight: bold } /* Generic.Strong */
code .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
code .gt { color: #a40000; font-weight: bold } /* Generic.Traceback */
code .kc { color: #204a87; font-weight: bold } /* Keyword.Constant */
code .kd { color: #204a87; font-weight: bold } /* Keyword.Declaration */
code .kn { color: #204a87; font-weight: bold } /* Keyword.Namespace */
code .kp { color: #204a87; font-weight: bold } /* Keyword.Pseudo */
code .kr { color: #204a87; font-weight: bold } /* Keyword.Reserved */
code .kt { color: #204a87; font-weight: bold } /* Keyword.Type */
code .ld { color: #000000 } /* Literal.Date */
code .m { color: #0000cf; font-weight: bold } /* Literal.Number */
code .s { color: #4e9a06 } /* Literal.String */
code .na { color: #c4a000 } /* Name.Attribute */
code .nb { color: #204a87 } /* Name.Builtin */
code .nc { color: #000000 } /* Name.Class */
code .no { color: #000000 } /* Name.Constant */
code .nd { color: #5c35cc; font-weight: bold } /* Name.Decorator */
code .ni { color: #ce5c00 } /* Name.Entity */
code .ne { color: #cc0000; font-weight: bold } /* Name.Exception */
code .nf { color: #000000 } /* Name.Function */
code .nl { color: #f57900 } /* Name.Label */
code .nn { color: #000000 } /* Name.Namespace */
code .nx { color: #000000 } /* Name.Other */
code .py { color: #000000 } /* Name.Property */
code .nt { color: #204a87; font-weight: bold } /* Name.Tag */
code .nv { color: #000000 } /* Name.Variable */
code .ow { color: #204a87; font-weight: bold } /* Operator.Word */
code .w { color: #f8f8f8; text-decoration: underline } /* Text.Whitespace */
code .mf { color: #0000cf; font-weight: bold } /* Literal.Number.Float */
code .mh { color: #0000cf; font-weight: bold } /* Literal.Number.Hex */
code .mi { color: #0000cf; font-weight: bold } /* Literal.Number.Integer */
code .mo { color: #0000cf; font-weight: bold } /* Literal.Number.Oct */
code .sb { color: #4e9a06 } /* Literal.String.Backtick */
code .sc { color: #4e9a06 } /* Literal.String.Char */
code .sd { color: #8f5902; font-style: italic } /* Literal.String.Doc */
code .s2 { color: #4e9a06 } /* Literal.String.Double */
code .se { color: #4e9a06 } /* Literal.String.Escape */
code .sh { color: #4e9a06 } /* Literal.String.Heredoc */
code .si { color: #4e9a06 } /* Literal.String.Interpol */
code .sx { color: #4e9a06 } /* Literal.String.Other */
code .sr { color: #4e9a06 } /* Literal.String.Regex */
code .s1 { color: #4e9a06 } /* Literal.String.Single */
code .ss { color: #4e9a06 } /* Literal.String.Symbol */
code .bp { color: #3465a4 } /* Name.Builtin.Pseudo */
code .vc { color: #000000 } /* Name.Variable.Class */
code .vg { color: #000000 } /* Name.Variable.Global */
code .vi { color: #000000 } /* Name.Variable.Instance */
code .il { color: #0000cf; font-weight: bold } /* Literal.Number.Integer.Long */